{% extends "page.html" %}

{% block subtitle %}{{ _('Groups') }}{% endblock %}

{% block breadcrumb_content %}
  <li class="active">{% link_for _('Groups'), controller='group', action='index', named_route=group_type + '_index' %}</li>
{% endblock %}

{% block page_header %}{% endblock %}

{% block page_primary_action %}
  {% if h.check_access('group_create') %}
    {% link_for _('Add Group'), controller='group', action='new', class_='btn btn-primary', icon='plus-square', named_route=group_type + '_new' %}
  {% endif %}
{% endblock %}

{% block primary_content_inner %}
  <h1 class="hide-heading">{{ _('Groups') }}</h1>
  {% block groups_search_form %}
    {% snippet 'snippets/search_form.html', form_id='group-search-form', type='group', query=c.q, sorting_selected=c.sort_by_selected, count=c.page.item_count, placeholder=_('Search groups...'), show_empty=request.params, no_bottom_border=true if c.page.items, sorting = [(_('Name Ascending'), 'title asc'), (_('Name Descending'), 'title desc')] %}
  {% endblock %}
  {% block groups_list %}
    {% if c.page.items or request.params %}
      {% if c.page.items %}
        {% snippet "group/snippets/group_list.html", groups=c.page.items %}
      {% endif %}
    {% else %}
      <p class="empty">
        {{ _('There are currently no groups for this site') }}.
        {% if h.check_access('group_create') %}
          {% link_for _('How about creating one?'), controller='group', action='new' %}</a>.
        {% endif %}
      </p>
    {% endif %}
  {% endblock %}
  {% block page_pagination %}
    {{ c.page.pager(q=c.q or '', sort=c.sort_by_selected or '') }}
  {% endblock %}
{% endblock %}

{% block secondary_content %}
  {% snippet "group/snippets/helper.html" %}
{% endblock %}
